@@ -17,7 +17,7 @@ def process_logs(transaction):
     program_id = '6EF8rrecthR5Dkzon8Nwu78hRvfCKubJ14M5uBEwF6P'
     response = call_solcatcher_ts('process-logs', signature=signature, slot=slot, program_id=program_id, logs=logs)
     return signature
-def get_pair_by_id(pair_id):
+def get_pair(pair_d=None,mint=None):
     try:
         raw_pair_data = call_solcatcher_db('/api/get_pair',pair_id=pair_id)
         pair_data = clean_pair_values(raw_pair_data)
